@@ -193,6 +193,15 @@ impl ScriptExtension {
         (self.first == 0) & (self.second == 0) & (self.third == 0)
     }
 
+    /// Returns the number of scripts in the script extension
+    pub fn len(self) -> usize {
+        if self.is_common_or_inherited() {
+            1
+        } else {
+            (self.first.count_ones() + self.second.count_ones() + self.third.count_ones()) as usize
+        }
+    }
+
     /// Intersect this `ScriptExtension` with another `ScriptExtension`. Produces `Unknown` if things
     /// do not intersect. This is equivalent to [`ScriptExtension::intersection`] but it stores the result
     /// in `self`
@@ -257,9 +266,9 @@ impl ScriptExtension {
         ext
     }
 
-    /// Iterate over the scripts in this string
+    /// Iterate over the scripts in this script extension
     ///
-    /// Will never yeild Script::Unknown
+    /// Will never yield Script::Unknown
     pub fn iter(self) -> ScriptIterator {
         ScriptIterator { ext: self }
     }
@@ -499,7 +508,7 @@ mod tests {
     #[bench]
     fn bench_ext_intersection(b: &mut Bencher) {
         b.iter(|| {
-            let e1 = test::black_box(script_extensions::ARAB_ROHG_SYRC_THAA);
+            let e1 = test::black_box(script_extensions::ARAB_ROHG_SYRC_THAA_YEZI);
             let e2 = test::black_box(script_extensions::BENG_DEVA_DOGR_GONG_GONM_GRAN_GUJR_GURU_KNDA_MAHJ_MLYM_NAND_ORYA_SIND_SINH_SYLO_TAKR_TAML_TELU_TIRH);
             test::black_box(e2.intersection(e1));
         })
